==> vkio-1.0.0.tar.gz: lib/models/groups.dart <==
import 'dart:convert';

import 'package:http/http.dart' as http;

import './apiexception.dart';

/// VK API Groups class
class Groups {
  /// Base API request url
  String _baseUrl = 'https://api.vk.com/method/groups';
  
  /// Group's or user's token
  String _token;

  /// API version
  String _version = '5.98';

  /// Groups
  Groups(String token) {
    this._token = token;
  }

  toString() {
    return 'Groups';
  }

  /// Send a [method] request with [params]
  Future<Map> _request(String method, [Map<String, String> params]) async {
    String url = this._baseUrl + '.$method';

    Map body = <String, String>{
      'access_token': this._token,
      'v': this._version,
      ...?params,
    };

    http.Response response = await http.post(
      url,
      body: body,
    );

    Map json = jsonDecode(response.body);

    if (json['error'] != null) {
      Map error = json['error'];

      throw new APIException(
        error['error_msg'],
        code: error['error_code'],
      ).error;
    }

    return json;
  }

  /// Add address
  Future<Map> addAddress([Map<String, String> params]) async {
    return this._request('addAddress', {
      ...?params,
    });
  }

  /// Add callback server
  Future<Map> addCallbackServer([Map<String, String> params]) async {
    return this._request('addCallbackServer', {
      ...?params,
    });
  }

  /// Add link
  Future<Map> addLink([Map<String, String> params]) async {
    return this._request('addLink', {
      ...?params,
    });
  }

  /// Approve request
  Future<Map> approveRequest([Map<String, String> params]) async {
    return this._request('approveRequest', {
      ...?params,
    });
  }

  /// Ban user
  Future<Map> ban([Map<String, String> params]) async {
    return this._request('ban', {
      ...?params,
    });
  }

  /// Create group
  Future<Map> create([Map<String, String> params]) async {
    return this._request('create', {
      ...?params,
    });
  }

  /// Delete address
  Future<Map> deleteAddress([Map<String, String> params]) async {
    return this._request('deleteAddress', {
      ...?params,
    });
  }

  /// Delete callback server
  Future<Map> deleteCallbackServer([Map<String, String> params]) async {
    return this._request('deleteCallbackServer', {
      ...?params,
    });
  }

  /// Delete link
  Future<Map> deleteLink([Map<String, String> params]) async {
    return this._request('deleteLink', {
      ...?params,
    });
  }

  /// Disable online
  Future<Map> disableOnline([Map<String, String> params]) async {
    return this._request('disableOnline', {
      ...?params,
    });
  }

  /// Edit group
  Future<Map> edit([Map<String, String> params]) async {
    return this._request('edit', {
      ...?params,
    });
  }

  /// Edit address
  Future<Map> editAddress([Map<String, String> params]) async {
    return this._request('editAddress', {
      ...?params,
    });
  }

  /// Edit callback server
  Future<Map> editCallbackServer([Map<String, String> params]) async {
    return this._request('editCallbackServer', {
      ...?params,
    });
  }

  /// Edit link
  Future<Map> editLink([Map<String, String> params]) async {
    return this._request('editLink', {
      ...?params,
    });
  }

  /// Edit manager
  Future<Map> editManager([Map<String, String> params]) async {
    return this._request('editManager', {
      ...?params,
    });
  }

  /// Enable online
  Future<Map> enableOnline([Map<String, String> params]) async {
    return this._request('enableOnline', {
      ...?params,
    });
  }

  /// Get user's groups
  Future<Map> get([Map<String, String> params]) async {
    return this._request('get', {
      ...?params,
    });
  }

  /// Get addresses
  Future<Map> getAddresses([Map<String, String> params]) async {
    return this._request('getAddresses', {
      ...?params,
    });
  }

  /// Get banned users
  Future<Map> getBanned([Map<String, String> params]) async {
    return this._request('getBanned', {
      ...?params,
    });
  }

  /// Get group by ID
  Future<Map> getById([Map<String, String> params]) async {
    return this._request('getById', {
      ...?params,
    });
  }

  /// Get callback confirmation code
  Future<Map> getCallbackConfirmationCode([Map<String, String> params]) async {
    return this._request('getCallbackConfirmationCode', {
      ...?params,
    });
  }

  /// Get callback servers
  Future<Map> getCallbackServers([Map<String, String> params]) async {
    return this._request('getCallbackServers', {
      ...?params,
    });
  }

  /// Get callback settings
  Future<Map> getCallbackSettings([Map<String, String> params]) async {
    return this._request('getCallbackSettings', {
      ...?params,
    });
  }

  /// Get catalog
  Future<Map> getCatalog([Map<String, String> params]) async {
    return this._request('getCatalog', {
      ...?params,
    });
  }

  /// Get catalog info
  Future<Map> getCatalogInfo([Map<String, String> params]) async {
    return this._request('getCatalogInfo', {
      ...?params,
    });
  }

  /// Get invited users
  Future<Map> getInvitedUsers([Map<String, String> params]) async {
    return this._request('getInvitedUsers', {
      ...?params,
    });
  }

  /// Get invites
  Future<Map> getInvites([Map<String, String> params]) async {
    return this._request('getInvites', {
      ...?params,
    });
  }

  /// Get longpoll server
  Future<Map> getLongPollServer([Map<String, String> params]) async {
    return this._request('getLongPollServer', {
      ...?params,
    });
  }

  /// Get longpoll settings
  Future<Map> getLongPollSettings([Map<String, String> params]) async {
    return this._request('getLongPollSettings', {
      ...?params,
    });
  }

  /// Get members
  Future<Map> getMembers([Map<String, String> params]) async {
    return this._request('getMembers', {
      ...?params,
    });
  }

  /// Get online status
  Future<Map> getOnlineStatus([Map<String, String> params]) async {
    return this._request('getOnlineStatus', {
      ...?params,
    });
  }

  /// Get requests
  Future<Map> getRequests([Map<String, String> params]) async {
    return this._request('getRequests', {
      ...?params,
    });
  }

  /// Get settings
  Future<Map> getSettings([Map<String, String> params]) async {
    return this._request('getSettings', {
      ...?params,
    });
  }

  /// Get token permissions
  Future<Map> getTokenPermissions([Map<String, String> params]) async {
    return this._request('getTokenPermissions', {
      ...?params,
    });
  }

  /// Invite user
  Future<Map> invite([Map<String, String> params]) async {
    return this._request('invite', {
      ...?params,
    });
  }

  /// Is user member?
  Future<Map> isMember([Map<String, String> params]) async {
    return this._request('isMember', {
      ...?params,
    });
  }

  /// Join group
  Future<Map> join([Map<String, String> params]) async {
    return this._request('join', {
      ...?params,
    });
  }

  /// Leave group
  Future<Map> leave([Map<String, String> params]) async {
    return this._request('leave', {
      ...?params,
    });
  }

  /// Remove user from group
  Future<Map> removeUser([Map<String, String> params]) async {
    return this._request('removeUser', {
      ...?params,
    });
  }

  /// Reorder link
  Future<Map> reorderLink([Map<String, String> params]) async {
    return this._request('reorderLink', {
      ...?params,
    });
  }

  /// Search for group
  Future<Map> search([Map<String, String> params]) async {
    return this._request('search', {
      ...?params,
    });
  }

  /// Set callback settings
  Future<Map> setCallbackSettings([Map<String, String> params]) async {
    return this._request('setCallbackSettings', {
      ...?params,
    });
  }

  /// Set longpoll settings
  Future<Map> setLongPollSettings([Map<String, String> params]) async {
    return this._request('setLongPollSettings', {
      ...?params,
    });
  }

  /// Unban user
  Future<Map> unban([Map<String, String> params]) async {
    return this._request('unban', {
      ...?params,
    });
  }
}

==> vkio-1.0.1.tar.gz: lib/models/groups.dart <==
import './api.dart';

/// VK API Groups class
class Groups {
  /// API class
  API _api;

  /// Groups
  Groups(API api) {
    this._api = api;
  }

  toString() {
    return 'Groups';
  }

  /// Add address
  Future<Map> addAddress([Map<String, String> params]) async {
    return this._api.request('addAddress', {
      ...?params,
    });
  }

  /// Add callback server
  Future<Map> addCallbackServer([Map<String, String> params]) async {
    return this._api.request('addCallbackServer', {
      ...?params,
    });
  }

  /// Add link
  Future<Map> addLink([Map<String, String> params]) async {
    return this._api.request('addLink', {
      ...?params,
    });
  }

  /// Approve request
  Future<Map> approveRequest([Map<String, String> params]) async {
    return this._api.request('approveRequest', {
      ...?params,
    });
  }

  /// Ban user
  Future<Map> ban([Map<String, String> params]) async {
    return this._api.request('ban', {
      ...?params,
    });
  }

  /// Create group
  Future<Map> create([Map<String, String> params]) async {
    return this._api.request('create', {
      ...?params,
    });
  }

  /// Delete address
  Future<Map> deleteAddress([Map<String, String> params]) async {
    return this._api.request('deleteAddress', {
      ...?params,
    });
  }

  /// Delete callback server
  Future<Map> deleteCallbackServer([Map<String, String> params]) async {
    return this._api.request('deleteCallbackServer', {
      ...?params,
    });
  }

  /// Delete link
  Future<Map> deleteLink([Map<String, String> params]) async {
    return this._api.request('deleteLink', {
      ...?params,
    });
  }

  /// Disable online
  Future<Map> disableOnline([Map<String, String> params]) async {
    return this._api.request('disableOnline', {
      ...?params,
    });
  }

  /// Edit group
  Future<Map> edit([Map<String, String> params]) async {
    return this._api.request('edit', {
      ...?params,
    });
  }

  /// Edit address
  Future<Map> editAddress([Map<String, String> params]) async {
    return this._api.request('editAddress', {
      ...?params,
    });
  }

  /// Edit callback server
  Future<Map> editCallbackServer([Map<String, String> params]) async {
    return this._api.request('editCallbackServer', {
      ...?params,
    });
  }

  /// Edit link
  Future<Map> editLink([Map<String, String> params]) async {
    return this._api.request('editLink', {
      ...?params,
    });
  }

  /// Edit manager
  Future<Map> editManager([Map<String, String> params]) async {
    return this._api.request('editManager', {
      ...?params,
    });
  }

  /// Enable online
  Future<Map> enableOnline([Map<String, String> params]) async {
    return this._api.request('enableOnline', {
      ...?params,
    });
  }

  /// Get user's groups
  Future<Map> get([Map<String, String> params]) async {
    return this._api.request('get', {
      ...?params,
    });
  }

  /// Get addresses
  Future<Map> getAddresses([Map<String, String> params]) async {
    return this._api.request('getAddresses', {
      ...?params,
    });
  }

  /// Get banned users
  Future<Map> getBanned([Map<String, String> params]) async {
    return this._api.request('getBanned', {
      ...?params,
    });
  }

  /// Get group by ID
  Future<Map> getById([Map<String, String> params]) async {
    return this._api.request('getById', {
      ...?params,
    });
  }

  /// Get callback confirmation code
  Future<Map> getCallbackConfirmationCode([Map<String, String> params]) async {
    return this._api.request('getCallbackConfirmationCode', {
      ...?params,
    });
  }

  /// Get callback servers
  Future<Map> getCallbackServers([Map<String, String> params]) async {
    return this._api.request('getCallbackServers', {
      ...?params,
    });
  }

  /// Get callback settings
  Future<Map> getCallbackSettings([Map<String, String> params]) async {
    return this._api.request('getCallbackSettings', {
      ...?params,
    });
  }

  /// Get catalog
  Future<Map> getCatalog([Map<String, String> params]) async {
    return this._api.request('getCatalog', {
      ...?params,
    });
  }

  /// Get catalog info
  Future<Map> getCatalogInfo([Map<String, String> params]) async {
    return this._api.request('getCatalogInfo', {
      ...?params,
    });
  }

  /// Get invited users
  Future<Map> getInvitedUsers([Map<String, String> params]) async {
    return this._api.request('getInvitedUsers', {
      ...?params,
    });
  }

  /// Get invites
  Future<Map> getInvites([Map<String, String> params]) async {
    return this._api.request('getInvites', {
      ...?params,
    });
  }

  /// Get longpoll server
  Future<Map> getLongPollServer([Map<String, String> params]) async {
    return this._api.request('getLongPollServer', {
      ...?params,
    });
  }

  /// Get longpoll settings
  Future<Map> getLongPollSettings([Map<String, String> params]) async {
    return this._api.request('getLongPollSettings', {
      ...?params,
    });
  }

  /// Get members
  Future<Map> getMembers([Map<String, String> params]) async {
    return this._api.request('getMembers', {
      ...?params,
    });
  }

  /// Get online status
  Future<Map> getOnlineStatus([Map<String, String> params]) async {
    return this._api.request('getOnlineStatus', {
      ...?params,
    });
  }

  /// Get requests
  Future<Map> getRequests([Map<String, String> params]) async {
    return this._api.request('getRequests', {
      ...?params,
    });
  }

  /// Get settings
  Future<Map> getSettings([Map<String, String> params]) async {
    return this._api.request('getSettings', {
      ...?params,
    });
  }

  /// Get token permissions
  Future<Map> getTokenPermissions([Map<String, String> params]) async {
    return this._api.request('getTokenPermissions', {
      ...?params,
    });
  }

  /// Invite user
  Future<Map> invite([Map<String, String> params]) async {
    return this._api.request('invite', {
      ...?params,
    });
  }

  /// Is user member?
  Future<Map> isMember([Map<String, String> params]) async {
    return this._api.request('isMember', {
      ...?params,
    });
  }

  /// Join group
  Future<Map> join([Map<String, String> params]) async {
    return this._api.request('join', {
      ...?params,
    });
  }

  /// Leave group
  Future<Map> leave([Map<String, String> params]) async {
    return this._api.request('leave', {
      ...?params,
    });
  }

  /// Remove user from group
  Future<Map> removeUser([Map<String, String> params]) async {
    return this._api.request('removeUser', {
      ...?params,
    });
  }

  /// Reorder link
  Future<Map> reorderLink([Map<String, String> params]) async {
    return this._api.request('reorderLink', {
      ...?params,
    });
  }

  /// Search for group
  Future<Map> search([Map<String, String> params]) async {
    return this._api.request('search', {
      ...?params,
    });
  }

  /// Set callback settings
  Future<Map> setCallbackSettings([Map<String, String> params]) async {
    return this._api.request('setCallbackSettings', {
      ...?params,
    });
  }

  /// Set longpoll settings
  Future<Map> setLongPollSettings([Map<String, String> params]) async {
    return this._api.request('setLongPollSettings', {
      ...?params,
    });
  }

  /// Unban user
  Future<Map> unban([Map<String, String> params]) async {
    return this._api.request('unban', {
      ...?params,
    });
  }
}
